@@ -11,13 +11,8 @@
 
 #include "downloadmanager.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include "qquickwebenginedownloaditem.h"
-using DownloadItem = QQuickWebEngineDownloadItem;
-#else
 #include <private/qquickwebenginedownloadrequest_p.h>
 using DownloadItem = QQuickWebEngineDownloadRequest;
-#endif
 
 DownloadsModel::DownloadsModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -70,3 +65,5 @@ void DownloadsModel::removeDownload(const int index)
     DownloadManager::instance().removeDownload(index);
     endRemoveRows();
 }
+
+#include "moc_downloadsmodel.cpp"
